library(testthat)
library(coinmarketcapr)

#test_check("coinmarketcapr")
